#[non_exhaustive]pub struct LayoutConfig {
pub sidebar_ratio: u16,
}Expand description
Public configuration and theming types. Layout configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Preferred sidebar width as a percentage of the terminal width.
The rendered sidebar is clamped to fit the active layout so the main pane keeps a usable width. Compact layouts clamp more aggressively than roomy layouts.