#[non_exhaustive]pub struct TuiConfig {
pub theme: Theme,
pub keymap: Keymap,
pub start_command: Option<String>,
pub layout: LayoutConfig,
}Expand description
Public configuration and theming types.
Top-level configuration for crate::Tui and crate::TuiApp.
Most applications only need to customize the theme or start_command.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.theme: ThemeTheme configuration.
keymap: KeymapKey bindings.
start_command: Option<String>Initial command path to select, using ::-separated command names such as
build::release.
Unknown paths leave the root command selected and show a non-error toast at startup.
layout: LayoutConfigLayout configuration.